==============
Citing Crappy
==============

If Crappy has been of help in your research, please reference it in your 
academic publications by citing one or both of the following articles :

- Couty V., Witz J-F., Martel C. et al., *Command and Real-Time Acquisition in Parallelized Python, a Python module for experimental setups*, SoftwareX 16, 2021, DOI: 10.1016/j.softx.2021.100848. (`link to Couty et al. <https://www.sciencedirect.com/science/article/pii/S2352711021001278>`_)
- Weisrock A., Couty V., Witz J-F. et al., *CRAPPY goes embedded: Including low-cost hardware in experimental setups*, SoftwareX 22, 2023, DOI: 10.1016/j.softx.2023.101348. (`link to Weisrock et al. <https://www.sciencedirect.com/science/article/pii/S2352711023000444>`_)

Here are the BibTex codes for referencing the articles :

.. code-block:: shell-session

    @article{COUTY2021100848,
             title = {CRAPPY: Command and Real-Time Acquisition in Parallelized Python, a Python module for experimental setups},
             journal = {SoftwareX},
             volume = {16},
             pages = {100848},
             year = {2021},
             issn = {2352-7110},
             doi = {https://doi.org/10.1016/j.softx.2021.100848},
             url = {https://www.sciencedirect.com/science/article/pii/S2352711021001278},
             author = {Victor Couty and Jean-François Witz and Corentin Martel and François Bari and Antoine Weisrock},
             keywords = {Control-command, Acquisition, Python, Experimental setup},
    }

.. code-block:: shell-session

    @article{WEISROCK2023101348,
            title = {CRAPPY goes embedded: Including low-cost hardware in experimental setups},
            journal = {SoftwareX},
            volume = {22},
            pages = {101348},
            year = {2023},
            issn = {2352-7110},
            doi = {https://doi.org/10.1016/j.softx.2023.101348},
            url = {https://www.sciencedirect.com/science/article/pii/S2352711023000444},
            author = {Antoine Weisrock and Victor Couty and Jean-François Witz and Lieven Thorrez and Pauline Lecomte-Grosbras},
            keywords = {Control-command, Acquisition, Python, Low-cost, Embedded hardware},
    }
